@@ -1,6 +1,6 @@
 package Code::TidyAll::Git::Precommit;
 {
-  $Code::TidyAll::Git::Precommit::VERSION = '0.17';
+  $Code::TidyAll::Git::Precommit::VERSION = '0.18';
 }
 use Capture::Tiny qw(capture_stdout capture_stderr);
 use Code::TidyAll;
@@ -82,7 +82,7 @@ tidyall'd
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -183,11 +183,22 @@ yourself or your developers as follows:
 
 =item *
 
-Create a directory called C<git> at the top of your repo (note no dot prefix)
+Create a directory called C<git/hooks> at the top of your repo (note no dot
+prefix).
+
+    mkdir -p git/hooks
 
 =item *
 
-Commit your pre-commit script in C<git/hooks/pre-commit>
+Commit your pre-commit script in C<git/hooks/pre-commit> containing:
+
+    #!/usr/bin/env perl
+
+    use strict;
+    use warnings;
+
+    use Code::TidyAll::Git::Precommit;
+    Code::TidyAll::Git::Precommit->check();
 
 =item *
 
@@ -200,7 +211,7 @@ Add a setup script in C<git/setup.sh> containing
 
 =item *
 
-Run C<git/setup.pl> (or tell your developers to run it) once for each new clone
+Run C<git/setup.sh> (or tell your developers to run it) once for each new clone
 of the repo
 
 =back
