@@ -1,8 +1,9 @@
 package Code::TidyAll::Plugin::JSBeautify;
 {
-  $Code::TidyAll::Plugin::JSBeautify::VERSION = '0.17';
+  $Code::TidyAll::Plugin::JSBeautify::VERSION = '0.18';
 }
-use IPC::System::Simple qw(run);
+use Capture::Tiny qw(capture_merged);
+use Code::TidyAll::Util qw(write_file);
 use Moo;
 use Try::Tiny;
 extends 'Code::TidyAll::Plugin';
@@ -13,7 +14,9 @@ sub transform_file {
     my ( $self, $file ) = @_;
 
     try {
-        run( sprintf( "%s --replace %s %s", $self->cmd, $self->argv, $file ) );
+        my $cmd = join( " ", $self->cmd, $self->argv, $file );
+        my $output = capture_merged { system($cmd) };
+        write_file( $file, $output );
     }
     catch {
         die sprintf( "%s exited with error - possibly bad arg list '%s'", $self->cmd, $self->argv );
@@ -32,7 +35,7 @@ Code::TidyAll::Plugin::JSBeautify - use js-beautify with tidyall
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
